==> webkitgtk_2.3.2.orig.tar.xz: webkitgtk-2.3.2/Source/WebKit2/UIProcess/API/gtk/WebKitCertificateInfoPrivate.h <==
/*
 * Copyright (C) 2013 Samsung Electronics Inc. All rights reserved.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public License
 * along with this library; see the file COPYING.LIB.  If not, write to
 * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301, USA.
 */

#ifndef WebKitCertificateInfoPrivate_h
#define WebKitCertificateInfoPrivate_h

#include "PlatformCertificateInfo.h"
#include "WebKitCertificateInfo.h"
#include "WebKitPrivate.h"

struct _WebKitCertificateInfo {
    _WebKitCertificateInfo(GTlsCertificate* certificate, GTlsCertificateFlags tlsErrors)
        : certificateInfo(certificate, tlsErrors)
    {
    }

    _WebKitCertificateInfo(WebKitCertificateInfo* info)
        : certificateInfo(info->certificateInfo)
    {
    }

    WebKit::PlatformCertificateInfo certificateInfo;
};

const WebKit::PlatformCertificateInfo& webkitCertificateInfoGetCertificateInfo(WebKitCertificateInfo*);

#endif // WebKitCertificateInfoPrivate_h

==> webkitgtk_2.3.5.orig.tar.xz: webkitgtk-2.3.5/Source/WebKit2/UIProcess/API/gtk/WebKitCertificateInfoPrivate.h <==
/*
 * Copyright (C) 2013 Samsung Electronics Inc. All rights reserved.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public License
 * along with this library; see the file COPYING.LIB.  If not, write to
 * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301, USA.
 */

#ifndef WebKitCertificateInfoPrivate_h
#define WebKitCertificateInfoPrivate_h

#include "WebKitCertificateInfo.h"
#include "WebKitPrivate.h"
#include <WebCore/CertificateInfo.h>

struct _WebKitCertificateInfo {
    _WebKitCertificateInfo(GTlsCertificate* certificate, GTlsCertificateFlags tlsErrors)
        : certificateInfo(certificate, tlsErrors)
    {
    }

    _WebKitCertificateInfo(WebKitCertificateInfo* info)
        : certificateInfo(info->certificateInfo)
    {
    }

    WebCore::CertificateInfo certificateInfo;
};

const WebCore::CertificateInfo& webkitCertificateInfoGetCertificateInfo(WebKitCertificateInfo*);

#endif // WebKitCertificateInfoPrivate_h
